L. El Kaoutit
Address: Universidad de Granada. Departamento de Álgebra.
Facultad de Educación y Humanidades de Ceuta. El Greco N10, 51002
Ceuta, Spain.
Date: March 2006
Abstract.
We show that the bicategory whose -cells are corings over rings
with local units is bi-equivalent to the bicategory of comonads in
(right) unital modules whose underlying functors are right exact and
preserve direct sums. A base ring extension of a coring by an
adjunction is introduced as well.
Key words and phrases:
Corings and comodules. Rings with local units. Comonads. Bicategories.
msc2000 Mathematics Subject Classification
16W30, 13B02.
1. Introduction
Corings over rings with identity have been intensively studied in the
last years. A detailed discussion can be found in
[8]. It is well known that any coring
entails a comonad (i.e., cotriple) in the category of right modules
over the base ring. The converse is also true for the case of
coalgebras, taking functors which are right exact and preserve direct
sums, as was checked in [11]. Thus, the
categorical study of corings and their comodules is entirely linked
to the study of certain comonads and their universal cogenerators
(see [11]) in non necessarily monoidal
categories. For instance, many new examples of corings can be built
using earlier constructions in comonads theory (e.g. the
distributive laws of J. Beck [5]), or just by
considering comonads with a special cogenerator.
In this paper, we study these relationships in the context of corings
over rings with local units in the sense of
[1, 2]. This class of rings arose
naturally in the definition of infinite comatrix corings, see
[13], [19] and
[9].
In what follows an additive covariant functor is said to be continuous
if it is right exact and preserves direct sums.
The paper is organized as follows. Section 2 is rather
technical, and it is devoted to introduce a -category with
objects (-cells) comonads in Grothendieck categories, using
earlier results from [24]. In Section
3, we extend a result of Watts [31] to the
case of rings with local units (Lemma 3.3), and use this to
prove that each comonad induces a coring whenever its underlying
functor is continuous (Proposition 3.5). In Section
4, we establish a bi-equivalence between the bicategory
of unital bimodules and the bicategory whose -cells are rings
with local units and having the categories of continuous functors
over unital right modules as Hom-Categories (Proposition 4.1,
compare with [20, Proposition 2.1]). We,
then, deduce an equivalence of categories between the category of
corings over a fixed ring with local units and the category of
comonads in right unital modules whose underlying functors are
continuous (Corollary 4.3). Lastly, we derive a
bi-equivalence between the bicategory of all corings over rings with
local units and the bicategory of comonads in right unital modules
with continuous underlying functors (Theorem 4.6). The left
version of these results is similarly obtained and will not be
considered. In Section 5 we apply results from Sections
2 and 3 to introduce a base ring extension
of a coring by an adjunction.
Throughout denotes a commutative ring with identity .
2. Review on the 2-category of comonads
In this section we observe that Grothendieck categories form a class
of objects (-cells) in a -category whose -cells are
continuous functors. These will be
needed to introduce the -category of comonads using the formalism
of [24]. For general definitions of bicategories
and their homomorphisms we refer the reader to the fundamental paper
[6].
Recall from [11] that a comonad (or cotriple)
in a category is a three-tuple
consisting of a functor and natural
transformations , such that
(2.1)
are commutative diagrams. It is well known from
[22] that any adjunction with
left adjoint to (notation ) induces a comonad in , where and
are, respectively, the unit and
the counit of this adjunction. Using the terminology of
[11, Proposition 2.1], we say that the adjunction cogenerates the comonad . Now, the dual
version of [11, Theorem 2.2] asserts that for
any comonad in , there exists a universal
cogenerator, that is, a category and an adjunction
cogenerating with the following universal
property: If is another cogenerator of
, then there exists a unique functor such that and . The objects of are referred to as
comodules, they are pairs consisting of an object
and a morphism in
such that
(2.2)
are commutative diagrams. A morphism in is a morphism
in , where , such that
(2.3)
is a commutative diagram. The functor is then the forgetful
functor for every comodule , and the functor
is defined by , for
any object and morphism of .
Given a comonad in , the Kleisli
[23] category , is defined as follows.
The objects of are the same as those of . For
each pair of objects , the morphism set is defined by
The composition law and identities are canonically derived using
and . As was proved in [23], there is an
adjunction cogenerating , where and
for any object and morphism
of , and ,
for any objects , and morphism of
. The unique factorizing functor is given as follows. The
adjunction gives a natural isomorphism
which defines a functor by , for any object , and , for any morphism
. Clearly , , and is a fully faithful functor.
Lemma 2.1.
Consider an adjunction , with unit and counit together with a comonad in .
Then
(1)
is a comonad in
.
(2)
There is a functor defined by
Proof.
(1) This is [22, Theorem 4.2].
(2) It is clear that
we have an adjunction
with which cogenerates the
comonad . Following the proof of the dual version of [11, Theorem
2.2], we obtain that the stated functor is the
well known unique factorization functor.
∎
Following [4], a morphism between
two comonads and in a category
is a natural transformation which turns commutative the following diagrams
(2.4)
where is the natural transformation defined by
(2.5)
Given a morphism of comonads , we have an
induction functor
defined by for any and the identity on
morphisms.
Example 2.2.
Let be any comonad in a category . Clearly
is morphism of comonads, where
is endowed with a trivial comonad structure. If we
consider any adjunction with and the associated comonad of Lemma 2.1, then
we can easily check that is also a
morphism of comonads in , where is the
comonad cogenerated by .
Next, we are going to look at the case in which certain comonads and their morphisms
form a set-category and try to interpret the above constructions by
means of functors between those categories. The following definition
makes sense after [10, Lemma 5.1],
where it was proved that, over Grothendieck category, natural
transformations between continuous functors form a set.
Definition 2.3.
Let be a Grothendieck category. We define the category of
comonads in and denote it by , as the
category whose objects are comonads in
with a continuous functor (thus it
also preserves inductive limits); and whose morphisms are natural
transformations satisfying the commutativity of the diagrams
(2.4).
With this definition we can give an elegant restatement of Lemma
2.1(1).
Proposition 2.4.
Let and be two Grothendieck categories together
with an adjunction , whose unit and counit are,
respectively, and . Assume that and are continuous functors.
Given another adjunction where is a Grothendieck
category and , are continuous functors. Then, we have the following composition
where
and are
functors defined as above.
Proof.
(1) We only show that
is a morphism of comonads where
and are comonads in .
We have
which shows that
the second diagram in equation (2.4) commutes. On the
other hand, we have
Thus the first diagram in equation (2.4) commutes for
, and .
(2) Straightforward.
∎
Using Definition 2.3, one can adapt the formalism
introduced in [24] (see also [27])
for monads in arbitrary -category, to the setting of Grothendieck
categories as follows: First, using [10, Lemma
5.1], we obtain a -category
constructed by the following data:
Objects (-cells): All Grothendieck categories.
-cells: An -cell from to is a
continuous functor .
-cells: Natural transformations.
Associated to this -category, we construct, as in
[24], the right Eilenberg-Moore -category of
comonads:
Objects (-cells): They are pairs
consisting of a Grothendieck category
and a comonad in such
that is a continuous
functor (i.e., is an object of
the category of Definition 2.3).
-cells: An -cell from to
(here ), is a pair consisting of a continuous
functor , and a natural transformation satisfying the commutativity of the following
two diagrams
(2.6)
The identity -cell for a given object
is provided by .
-cells: Given and
two -cells from to , a
-cell is a natural
transformation turning commutative the
following diagram
(2.7)
The category constructed by all and -cells from
to will be denoted by
. The laws composition are given as
follows. Let , , and
be three -cells from to
with -cells and
. Then
(2.8)
Given and two -cells from
to , together with -cells
and
, the vertical
composition is given by
(2.9)
The horizontal composition is defined by
(2.10)
Associated to an -cell , there is a functor connecting the
universal cogenerators. Namely, there is an additive functor
(2.11)
sending
which clearly
turns commutative the following diagram
(2.12)
As in the case of an arbitrary -category [24],
one can substitute the above -cells (reduced forms) by the
unreduced forms, that is, natural transformations of the form
satisfying adequate conditions. The
bijection between reduced forms and unreduced forms established in
[24] for monads in –category, is interpreted
in our setting by the forthcoming proposition whose proof is based
upon the following. Recall that an object of an additive
category with direct sums and cokernels, is said to be a
subgenerator, if every object of is a sub-object of
a -generated one.
Lemma 2.5.
Let be a Grothendieck category and be an
object of the category . Then is an
additive category with direct sums and cokernels. Furthermore, if
is a generator of then is a
subgenerator of .
Proof.
It is immediate since preserves direct sums and cokernels.
∎
Proposition 2.6.
Let and be two Grothendieck categories, and
, . Considering and two
-cells from to , with the
associated functors as in equation (2.11), then the
natural transformations form a
set. Moreover, there is a bijection
explicitly given by
where for every object , .
Proof.
We first prove that is a set. To
do this, we follow the proof of [10, Lemma
5.1]. Let two natural
transformations and a generator of . So
is a sub-generator of , by Lemma
2.5. We claim that if then .
Considering any object of with an epimorphism in , for some set ,
we obtain a diagram
of morphisms of
. Since , we
have
By hypothesis, Lemma 2.5 and diagram
(2.12), we know that preserves
epimorphisms. Therefore, , as is an epimorphism. This
implies that
Applying the functor and
using the diagram (2.12) for , we get
Composing with the map
, we obtain that in , that is,
in ,
and this proves the claim.
For the stated bijection, we only prove that the mutually inverse
maps are well defined. Starting with a -cell , and taking an arbitrary object , we need
to demonstrate that is a morphism
of the category , so
Obviously is natural. Conversely, starting with a
natural transformation , its image is the natural transformation defined in every object by
; we need to
show that satisfies the -cell condition. In one hand, we have
On the other hand, we have
Therefore, , for every object , and this gives the
needed condition.
∎
3. Comonads and corings over rings with local
units
We will consider rings without identity although we assume that a set
of identities is given. Following [1] (see also
[2] and [3]) a –module
is said to be a ring with local units if for every
in , there exists an idempotent element (the set
of all idempotent elements) such that
We say that is a unity for the set .
This is equivalent to say that for every , there exists
a ring with identity of the form for some idempotent
element such that . For instance, every
induced ring from a –additive small category is a ring with
local units, in such case it is a ring with enough orthogonal idempotents,
see [17] and [16].
For any right –module (i.e., a -module with
associative -linear right -action ), denotes the right -submodule
A morphism between two rings with local units is a morphism of rings
(i.e., compatible with multiplications)
satisfying the following condition: For every , there
exists such that . Observe
that this condition is equivalent to say that for every , there exists such that .
The construction of the usual tensor product over rings with
identity can be directly transferred to rings with local units, and
the most useful properties of this product are preserved. We use the
same symbol to denote the tensor product between
–modules and –linear morphisms for any ring with local units
.
Let be a ring with local units, and . The
underlying –module of the right –module is a direct
summand of with decomposition . Associated to there are two –linear natural
transformations
(3.13)
for every right –module . Moreover, if is an
–bimodule ( is another ring with local units), then
and are clearly right –linear.
Taking another idempotent and a right –linear map, there are two commutative diagrams
(3.14)
where is the left multiplication
by , and any right –module. Following
[1], there is a partial ordering on defined by
for every . Taking any right –module, and such that , we can define a canonical
injection , . Furthermore, if , then it is clear that
, thus
is a directed system of
–submodule of . In this way it is obvious that and
A right –module is said to be unital if (or as right –module, where the isomorphism
should be given by the right –action). Equivalently, for every
element , there exists such that .
We denote by the full subcategory of the category of
right –modules whose objects are all unital right –modules.
An easy argument shows that is the largest unital right
–submodule of the right –module . On the other hand, a
right –module is unital if and only if in
the category of –modules. Given another ring with local
units, an unital –bimodule is a
–bimodule which is unital as a left –module and as a
right –module. Over the same ring, an –bimodule is
unital if and only if for every , there exists such that . In this way a morphism of rings
with local units induces a structure of an
unital –bimodule over , and preserves the usual adjunction
between the categories of unital right modules
The definition of corings over rings with identity as it was introduced
in [28] can be directly extended, using unital
bimodules, to rings with local units. Let be a ring with local
units, an –coring is a three-tuple consisting of an unital –bimodule and
two –bilinear maps
such that and
. A morphism of
–corings is an –bilinear map which satisfies and . We denote by the category of
all –corings and their morphisms.
A right –comodule is a pair consisting
of an unital right –module and a right –linear map
, called right
–coaction, such that
and . A
morphism of right –comodules is a right –linear map
satisfying . Right
–comodules and their morphisms form a not necessarily
abelian category which we denote by (see
[14, Section 1]). For every unital
right –module the pair
is clearly a right
–comodule. This establishes in fact a functor with the forgetful functor
as a left adjoint (see
[21]).
Example 3.1.
Of course every ring with local units is trivially an
–coring with comultiplication the isomorphism and counit the identity map .
(1)
[28]. Let be a
morphism of rings with local units and consider the unital
–bimodule with the following two maps
where such that and
; that is, is a unity for both and . To check
that is independent of the choice of the
unity, let us consider another unity for
both and . By definition there exists a unity for and . Of course is also a
unity for both and . Now, we have
Similarly, we get , and so
is independent from the choice of . An
easy verification shows now that is an –coring.
(2)
Let be an unital
–bimodule over a ring with local units . Consider the direct
sum of an –bimodules together with the
–bilinear maps
where such that and . Let
us check that is a well defined map. First we observe that a
common unity for and does always exist. If
is another unity for and , then one can consider a unity for and . Therefore, we have
In the same way, we get , and thus is independent from
the choice of the unity . The three-tuple
is easily proved to be an –coring.
(3)
[12]. Let be an unital bimodule
over rings with local units and such that is a
finitely generated and projective unital right module with finite right
dual basis where . That is, , for every . It is well known that
is also an unital –bimodule, and thus is an unital –bimodule. Furthermore, there
exist two –bilinear maps
The canonical isomorphism implies that is
independent from the choice of this right dual basis, and that
is an
–coring. This coring is known as the finite comatrix
coring associated to .
Example 3.2.
To take a specific example of finite comatrix corings over rings
with local units, we consider the so called finitely
orthogonal Rees matrix rings extensively investigated in
[2]. Following [3, Example 2]
(see also [2] for notions occurring here), let
be a ring with identity, and a Rees matrix ring over with
canonical decompositions , and . If is left-right finitely
orthogonal with respect to [2, Definition
4.2], then one can easily prove that is a ring
with local units. On the other hand, if we take
, then the associated finite comatrix
–coring is given by the –bimodule , and
its counit is just the above isomorphism sending . Therefore, we have an isomorphism of categories
via this counit (recall
that the counit is always a morphism of corings). Since the right
–comodule is clearly a generator of
, we deduce following Gabriel-Popescu’s
Theorem [18] that is a
faithfully flat module (here coincides with the endomorphism
ring of this comodule). Thus, establishes an equivalence of
categories by using the non unital version of the generalized
Descent Theorem [12, Theorem 3.10]. In
conclusion, is Morita equivalent to , and thus to ,
which gives an alternative proof of [3, Example
2].
From now on, we fix , rings with local units. Let be a continuous functor
(thus it also preserves inductive limits). As in the case of rings with identity
[31], next we will show that is naturally
isomorphic to the tensor product functor. Another approach,
concerning functors valued in abelian groups was given in
[15].
The structure of an –bimodule over comes out by the
composition map
(3.15)
where is the left multiplication by
. In the same way we get an –biaction over
(-times).
Therefore, one can consider the functor . Now, let’s start with an arbitrary idempotent
element , and consider the composed right
–linear map
(3.16)
where is the canonical injection, and
is the map defined in equation
(3.13). If we take another idempotent
element and a right –linear map, then by
equation (3.14), we get a commutative diagram like this
which shows that is natural over the set of right
–modules . Using the projections
and the maps defined in
equation (3.13), we can also construct a right –linear
map
Let be a continuous functor. For every idempotent
, we have
In particular extended uniquely to a natural
isomorphism
and becomes a left unital –module,
and thus an unital –bimodule.
Proof.
By definition, the left –action of is given by the rule
Fixing an arbitrary idempotent . So
for every , , and this shows the first
equality. To check the second equality, take and
compute
is clearly extended to unital right –modules of
the form ( and are sets).
Since preserves direct sums, this extension is also an
isomorphism of unital right –modules. By Mitchell’s
Theorem [25, Theorem 4.5.2] ([26, Theorem
3.6.5]), extends uniquely to a natural
isomorphism over
all unital right –modules.
We need to show that is a left unital –module. We have
seen that for every idempotent
via . Since preserves inductive limits, we get
which implies that is left unital and this finishes the
proof.
∎
The following lemma can be deduced from
[8, 39.5]. For the sake of completeness,
we include a detailed proof.
Lemma 3.4.
Let , and be three rings with local units. We denote by
the natural isomorphism of Lemma 3.3
associated to the continuous functor .
(a)
Let be two continuous functors. Assuming that there exists a
natural transformation , then
(1)
The morphism is
–bilinear.
(2)
For every unital right –module
, we have a commutative diagram
(b)
Let and be two continuous functors.
Then we have and the following diagram of natural transformations
commutes
Proof.
. By definition, we only need to show that is left
–linear. For every element , we have since is
natural and is right –linear. Hence ,
for every pair of elements .
. Assuming that is of the form for some
idempotent element , we obtain
For the general case we use a free presentation where , are sets, and the previous case taking
into account the hypothesis done over the stated functors.
Straightforward.
∎
It is clear that any –coring
induces, by the three-tuple
,
a comonad in . Now, consider a comonad in
such that is a continuous functor. Our next goal is to prove
that admits a structure of an –coring. Notice that this
has been already observed in [11, p. 398] (without
proofs) in the case of commutative rings with identity.
We begin by introducing some convenient notations. Denote by
the canonical natural isomorphism, and by
the
natural isomorphism of Lemma 3.3 associated to the continuous functor .
For every element ,
stills denoting the left
multiplication by .
Proposition 3.5.
Let be a ring with local units, and a comonad
in such that is a continuous functor. Then
is an
–coring.
Proof.
By Lemma 3.3, admits a structure of unital
–bimodule. The maps and are –bilinear by
Lemma 3.4(a)(1).
By hypothesis, we have the following diagram
where the rectangle is
commutative by equation (2.1), and by the
naturality of . Applying Lemma 3.4 to the
natural transformation , we get the
commutativity of the rectangle . Lastly, Lemma 3.4
applied this time to , gives the commutativity of the rectangle
. Therefore, the total diagram is commutative; whence
is coassociative. The left counitary property is shown by the
following diagram
which is
commutative by the naturality of and equation
(2.1). Now, this last equation together with Lemma
3.4 applied to give
the commutative diagram
which leads to the right counitary property, and
this finishes the proof.
∎
Let be a ring with local units, and a comonad
in . Consider the universal cogenerator of this comonad,
that is, an adjunction such that ,
and where is the category of comodules over
. The functor is then the forgetful functor:
, for every comodule , and the functor
is defined over objects by , for every
right unital –module . Given an –coring
it is easily seen that the
canonical adjunction is
the universal cogenerator of the associated comonad
in . The following proposition compares the cogenerator of
the comonad with the canonical adjunction
associated to the coring of Proposition 3.5.
Proposition 3.6.
Let be a ring with local units, and a comonad
in such that is a continuous functor with the
universal cogenerator . Considering as an –coring
with the structure of Proposition 3.5, we obtain an
isomorphism of categories
such that , and is a natural isomorphism.
Proof.
Given an object of , we get a diagram
(3.18)
The rectangles and are by definition commutative.
Applying Lemma 3.4 consecutively to the natural
transformations and , we obtain the commutativity
of rectangles and (here the natural isomorphism
associated to the functor is
,
see Lemma 3.4(b)). Thus, the whole diagram is commutative
which shows the coassociativity of the map . We also have another commutative diagram
Therefore,
is a right
–comodule. Now any morphism in the category entails a commutative
diagram
Hence
defined by
is a well defined functor with inverse
defined by
Clearly the underlying
right –module of coincides with that of
. That is . The
commutative rectangles and in diagram (3.18)
assert that is
an isomorphism of right –comodules, for every right unital
module , and this leads to the stated natural
isomorphism .
∎
Remark 3.7.
Of course one can work with left unital modules, and prove
similar results concerning functors which are right exact and
preserve direct sums and the induced corings from their comonads. In
this paper we only work with right unital modules. The left-right
relationship is omitted.
4. The bi-equivalence of bicategories
In this section we define the bicategory of corings over rings with
local units in the same way as in
[7], using general methods from
[24]. Next, we establish a bi-equivalence between
this bicategory and the -category of comonads in right unital
modules over rings with local units as it was defined in Section
2.
In what follows denotes the bicategory of unital bimodules
(i.e. -cells are all rings with local units,
Hom-Categories are categories of unital bimodules). The multiplications
are given by the tensor product bi-functors. Let us consider as in
Section 2, the -category whose
-cells are all Grothendieck categories of the form for
some ring with local units , and whose Hom-Categories consists of continuous functors. The multiplications are given by the usual
compositions of functors and natural transformations. The identity
-cell of a given -cell is the identity functor
. There is another bicategory which we denote by
whose class of -cells is the class of all rings
with local units, and with the same Home-Categories . Next, we formulate our results using the
bicategory instead of .
Proposition 4.1.
Keep the above notations. There exists a bi-equivalence of
bicategories given locally by the
functors
for every pair of ring
with local units .
Proof.
It will be done in three steps.
Step.1. Homomorphism of bicategories. The morphism
is the identity on the class of objects ( and
have the same class of objects). Taking two rings with local units
and , the stated functor is well defined
thanks to Lemmata 3.3 and 3.4(1). We need to show
its compatibility with the horizontal and vertical multiplications.
So let be another ring with local units and consider two
morphisms: in the category , and in the category
. By Lemma 3.4(1),
the morphism
is –bilinear, where and is the
natural transformation of Lemma 3.3. Moreover, applying Lemma
3.4, we obtain the following commutative diagram
This implies that is a natural
isomorphism. Clearly , and the compatibility with the
associativity, left and right multiplications by identities -cell
is fulfilled. Therefore, the pair establishes
a homomorphisms of bicategories from to .
Step.2. Local equivalences of Hom-Categories. Given two rings
with local units and , and consider the stated functor
. Define the functor acting on
objects by and on morphisms by . It is clear that gives a natural
isomorphism , for any functor . That is .
Conversely, for any –bimodule , we have a natural
isomorphism of bimodules . That is . Therefore,
are equivalences of Hom-Categories.
Step.3. Surjectivity up to equivalences. It is immediate since
and have the same class of objects which are
not altered by .
∎
Remark 4.2.
As was pointed by the referee there is an alternative proof of
Proposition 4.1 which uses results from
[20]. There, firm rings (resp. firm modules)
(see Remark 5.6 for definitions) were termed regular algebras
(resp. regular modules). The regularity of a functor ([20, Definition 1.5]) between
categories of firm modules over firm rings and , means that
is a firm -bimodule. Rings with local units are firm
rings. So by Lemma 3.3, right exact and direct sums preserving
functors (i.e., continuous) are regular. Hence Proposition 4.1
follows by [20, Proposition 2.1]. Another
way to obtain Proposition 4.1 for rings with orthogonal
idempotents, is by using the arguments done before [20, Section
2]. For a given ring with a set of
orthogonal idempotents (i.e., ), one can construct a right
-linear map such that
is a section for
the multiplication, where is the right -linear map
induced be tensoring with a fixed element of (see [20, page
142]). Here is defined as follows:
If , and the associated
idempotents such that , we then take .
By , we denote the category of all comonads in
whose underlying functors are right exact and preserve
direct sums, that is, the category of Definition 2.3
associated to the Grothendieck category . The following
corollary is a direct consequence of Propositions 4.1 and
3.5.
Corollary 4.3.
Let be a ring with local units. Then the functor
defined by
establishes an equivalence of categories.
The right Eilenberg-Moore bicategory associated to is
given by following corollary which is the non-unital version of
[7, 2.1]
Corollary 4.4.
The following
data form a bicategory :
-cells: corings i.e.,
is a ring with local units and is an –coring.
-cells: From to
are pairs consisting of an unital
–bimodule and an –bilinear map compatible
with comultiplications and counits, that is, satisfies
(4.19)
where the first equality is up to the isomorphism . The identity -cells for a given coring
is given by the pair
.
-cells: From to are
–bilinear maps
satisfying
(4.20)
Laws composition are defined as in
[7, 2.1], and given by
(4.21)
If and are -cells, then
(4.22)
The resulting category of all and -cells from
to is denoted by
.
Let’s keep now the notations of Section 2. Then the right
Eilenberg-Moore -category associated to is defined as
follows
Corollary 4.5.
The following data form a -category :
-cells: They are pairs , that
is, where is a ring
with local units (i.e., is a continuous functor).
-cells: From to
is a pair consisting of a continuous
functor and a natural transformation satisfying the commutativity of diagrams in equation
(2.6)
-cells: Given and
two -cells from to , a -cell is a natural transformation
satisfying the commutativity of diagram
in equation (2.7).
The category obtained by all and -cells from
to is denoted by
.
The following is our main result of this section.
Theorem 4.6.
There is a bi-equivalence between the bicategory of
corings over rings with locals units (Corollary 4.4), and
the bicategory whose objects are comonads with continuous
underlying functors over right unital modules (Corollary
4.5). This bi-equivalence is locally induced by the functors
defined by
where are the natural isomorphisms of Lemma
3.3, and where (resp. ) is sent to
(resp. to ) is the coring constructed in Proposition
3.5.
Proof.
It is a consequence of Proposition 4.1 and [24, Remark
1.1].
∎
Remark 4.7.
If we want to study any aspect in the right Eilenberg-Moore
bicategory , then it is convenient, using the local
equivalences stated in Theorem 4.6, to
transfer this study to the -category . The local
equivalences in the other direction are given by the functors
defined
by
where (resp. ) is the comonad induced by the coring
(resp. by ). These local
equivalences are not in fact given by [24, Remark
1.1]. Their construction was given separately
using direct computations.
5. Base ring extension of a coring by an adjunction
In this section we apply results from Sections 2 and
3, to extend the notion of base ring extension of a
coring by a (finitely generated and projective) module, introduced
in [7], to the case of rings with
local units. This will give a new class of corings over rings with
local units which includes some infinite comatrix corings
[13].
The following proposition characterizes an adjunction between right
unital modules with continuous functors (i.e. right exact and direct sums preserving functors).
Proposition 5.1.
Let and be two rings with local units. The following
statements are equivalent.
(i)
There is an adjunction with left adjoint
to , and such that , are continuous functors.
(ii)
There is an unital –bimodule such
that is finitely generated and projective unital right
–module, for every .
Proof.
. We denote by
the unital right dual of
. The bi-actions are defined as follows: For , , and , we have
This is clearly the unital part of the
–bimodule . The unit of the adjunction is given by
(5.23)
where such that , and
is the finite right dual basis for ,
and is the canonical projection. We
denote by the composition
We claim that
, for every such that . We have
and this proves the claim. Next, we prove that is
independent from the choice of . So, let’s fix an arbitrary
element and let be another unity for
(i.e., ). We consider as before the induced set
by the dual basis of
, where . Henceforth, its
remains to prove that
So, let such that and , and
consider again its corresponding set , where . Using elementary arguments, one can directly check
that
where is the canonical injection. On the
other hand, we have . Taking
all these equalities into account, we compute
Similar computation entails the equality
and this proves
the desired independence. Therefore, is a well defined
right -linear map, for every right unital –module .
Clearly, is a natural
transformation. The counit is given by
(5.24)
Lastly, one can easily show that
for
every pair of unital modules which implies the desired
adjunction taking and
.
. By Lemma 3.3 we know that
and are unital bimodules, and that , are natural
isomorphisms. Taking , and , we deduce that
is a right
–linear isomorphism. Henceforth, it remains to show that
is a finitely generated and projective module, for every . So, the natural isomorphism of the stated adjunction
gives us the following chain of natural isomorphisms
for every . That is, the
functor preserves inductive limits, and so
is a finitely generated and projective –module for every
.
∎
Remark 5.2.
Considering an unital –bimodule, we can easily check,
using the partial ordering on idempotent elements, that
as right unital
-modules. In fact is a split
direct system of right unital -module (see [29, Section
1]). If we assume that satisfies condition
of Proposition 5.1, then is locally
projective in the sense of [3],
equivalently, it is strongly locally projective in the sense of
[29, Theorem 2.17].
Remark 5.3.
Let , , and be rings with local units. Consider
(respectively ) an unital –bimodule (respectively
–bimodule) such that (respectively ) is
finitely generated and projective unital right –module
(respectively –module), for every
(respectively ). Then is an
unital –bimodule such that is
finitely generated and projective unital right –module, for
every . Furthermore, if we put
(respectively
), then
(5.25)
is an isomorphism of unital –bimodules. Effectively, let any idempotent element, so there exists an unital
right –module such that
where each . Applying the tensor product , we
obtain
an isomorphism of unital right
–modules. Since the right hand module is a finitely generated and
projective –module, we get that is also
finitely generated and projective as an –module, and this proves the
first claim. Now, using the adjunctions arising from the proof of
Proposition 5.1 and the usual Hom-Tensor adjunction,
we get the isomorphism of equation (5.25).
It is convenient to adopt the notations of the proof of
Proposition 5.1. Thus, if is any –bimodule
we denote by . When
is a finitely generated and projective right –module,
for some , we consider the set where
is the finite dual basis for , where
and is the canonical projection.
Corollary 5.4.
Let and be two rings with local units together with an
unital –bimodule and a –coring
. Assume
that is finitely generated and projective module for every
. Then the unital –bimodule admits the structure of an
–coring with comultiplication defined by
where is
the finite set induced by the dual basis of , where such that , , , and
where . The counit is defined by
Proof.
By Proposition 5.1, we know that is left adjoint to
with unit
and counit given explicitly by equations (5.23) and
(5.24). Applying Lemma 2.1(1) to the comonad
in , we obtain a new
comonad in with
Now, Proposition 3.5 implies that admits the
structure of an –coring. Since is obviously an isomorphism
of unital –bimodules, this structure can be transferred to
with
comultiplication and counit computed explicitly from the maps
and . This, in fact, leads exactly to the stated
structure.
∎
Recently, in [19] and
[9] new generalizations of
infinite comatrix corings, earlier introduced in
[13], were given in the context of non-unital
(firm) rings. The following example gives another way to construct infinite comatrix corings by
using Corollary 5.4.
Example 5.5.
Assume that is a ring with identity , and denote by
the full subcategory of all finitely generated and
projective unital right –modules. Consider a
–additive small category and its induced ring with enough
orthogonal idempotents : These are , where each of the ’s is the
image of the identity . Given an
additive faithful functor , we
get an unital –bimodule . It is clear that , for every object . Therefore,
is a finitely generated and projective right –module,
for every . Finally, considering as a trivial
–coring, we obtain by Corollary 5.4 an -coring
, where .
Remark 5.6.
Rings with local units are in fact a sub-class of firm rings. Recall
that an associative ring is firm if the multiplication
is an isomorphism. Unital modules are extended
to firm modules, i.e. a right –module with action
an isomorphism of right -modules. The
results of this paper can be extended to this class of rings by
using the categorical version of Lemmata 3.4 and
3.3 stated in [8, 39.3, 39.5] with
firm base rings. The fact that right exact and direct sums
preserving functors between firm modules are naturally isomorphism
to the tensor product functors, has been recently proved by J.
Vercruysse in [30, Theorem 3.1] (see also
[20, Proposition 1.6]). A characterization
of an adjunction whose both functors are right exact and preserve
direct sums (as in Proposition 5.1) was extended to the
case of firm modules in [30, Theorem 2.4].
Acknowledgements
I would like to thank my supervisor Professor J. Gómez-Torrecillas
for helpful comments. I also would like to thank the referee for her
or his suggestions, for pointing out a short proof of Theorem
4.6, and also for drawing my attention to the reference
[20]. This research was supported by grants
MTM2004-01406 and P06-FQM-1889.
References
[1]
G. D. Abrams, Morita equivalence for rings with local units,
Commun. Algebra 11 (1983), no. 8, 801–837.
[2]
P.N. Ánh and L. Márki, Rees matrix rings, J.
Algebra 81 (1983), 340–369.
[3]
P.N. Ánh and L. Márki, Morita equivalence for rings
without identity, Tsukuba J. Math. 11 (1987), no. 1,
1–16.
[4]
R. Bautista, L. Colavita, and L. Salmerón, On adjoint
functors in representation theory, Lecture Notes in Math., vol.
903, Springer-Verlag, 1981, pp. 9–25.
[5]
J. Beck, Distributive laws: In Seminar on Triples and
Categorical Homology Theory. Lecture Notes in Math., vol. 80,
Springer-Verlag, 1969, pp. 119–140.
[6]
J. Bénabou, Introduction to bicategories: In Report of the
Midwest Category Seminar. Lecture Notes in Math., vol. 47,
Springer-Verlag, 1967, pp. 1–77.
[7]
T. Brzeziński, L. El Kaoutit, and J. Gómez-Torrecillas,
The bicategories of corings, J. Pure Appl. Algebra
205 (2006), 510–541.
[8]
T. Brzeziński and R. Wisbauer, Corings and Comodules, London
Math. Soc. Lect. Note Ser.309, Cambridge University
Press, Cambridge, 2003.
[9]
S. Caenepeel, E. De Groot, and J. Vercruysse, Constructing
infinite comatrix corings from colimits, Appl. Categor. Struct.
14 (2006), 539–565.
[10]
F. Castaño Iglesias, J. Gómez-Torrecillas, and
C. ǎstǎsescu, Frobenius functors:
Aplications, Commun. Algebra 27 (1999), no. 10,
4879–4900.
[11]
S. Eilenberg and J. C. Moore, Adjoint functors and triples,
Illinois J. Math. 9 (1965), 381–398.
[12]
L. El Kaoutit and J. Gómez-Torrecillas, Comatrix corings:
Galois coring, Descent theory, and a structure theorem for
cosemisimple corings, Math. Z. 244 (2003), 887–906.
[13]
L. El Kaoutit and J. Gómez-Torrecillas,, Infinite comatrix
corings, Int. Math. Res. Notices 39 (2004), 2017–2037.
[14]
L. El Kaoutit, J. Gómez-Torrecillas, and F. J. Lobillo,
Semisimple corings, Algebra Colloq. 11 (2004),
no. 4, 427–442.
[15]
J. Fisher Palmquist and D. C. Newell, Bifunctors and adjoint
pairs, Trans. Amer. Math. Soc. 155 (1971), no. 2,
293–303.
[16]
K. R. Fuller and H Hullinger, Rings with finiteness
conditions and their categories of functors, J. Algebra 55
(1978), 94–105.
[17]
P. Gabriel, Des catégories abéliennes, Bull. Soc.
Math. France 90 (1962), 323–448.
[18]
P. Gabriel and N. Popescu, Caractérisation des
catégories abélienne avec générateurs et limites
inductives exactes, C. R. Acad. Sci. Paris 258 (1964),
4188–4191.
[19]
J. Gómez-Torrecillas and J. Vercruysse, Comatrix corings and
Galois comodules over firm rings, Algebra Rep. Theory 10 (2007), 271–306.
[20]
F. Grandjean and E.M. Vitale, Morita equivalence for regular
algebras, Cahiers Topologie Géom. Différentielle Catég.
XXXIX (1998), no. 2, 137–153.
[21]
F. Guzman, Cointegration, Relative Cohomology for
Comdules, and Coseparable Coring, J. Algebra 126
(1989), 211–224.
[22]
P. J. Huber, Homotopy theory in general categories, Math.
Ann. 144 (1961), 361–385.
[23]
H. Kleisli, Every standard construction is induced by a pair
of adjoint functors, Proc. Amer. Math. Soc. 16 (1965),
544–546.
[24]
S. Lack and R. Street, The formal theory of monads II, J.
Pure Appl. Algebra 175 (2002), 243–265.
[25]
B. Mitchell, Theory of Categories, New York and
London ed., Academic Press, 1965.
[26]
N. Popescu, Abelian Category with Application to Ring
and Modules, Academic Press London and New York, 1973.
[27]
R. Street, The formal theory of monads, J. Pure Appl. Algebra
2 (1972), 149–168.
[28]
M. Sweedler, The predual theorem to the Jacobson-Bourbaki
theorem, Tran. Amer. Math. Soc. 213 (1975), 391–406.
[29]
J. Vercruysse, Local units versus local projectivity.
Dualisations: Corings with local structure maps, Commun.
Algebra 34 (2006), 2683–2711.
[30]
J. Vercruysse, Equivalences between categories of modules and
categories of comodules, arXiv:math.RA/0604423.
[31]
C. E. Watts, Intrinsic characterization of some additive
functors, Proc. Amer. Math. Soc. 11 (1960), 5–8.